// maze.h
// Jace Miller

#ifndef MAZE_H
#define MAZE_H

#include "genlib.h"
#include "graphics.h"
#include <windows.h>

// GenerateMaze() takes three arguments.  The first two describe the size of the
// maze to be generated, specifically, the width and height measured in cells.
// The third parameter is the number of milliseconds to wait between drawing
// segments of the path being taken.  It is optional, and set to 150 by default.
void GenerateMaze(int width, int height, int delay = 150);

// PrintMaze() draws the maze that was generated with GenerateMaze().  A green
// square with an 'X' drawn inside marks the starting location of the avatar.
void PrintMaze();

// Moves the avatar forward one cell in the direction it is currently facing,
// unless it is facing a wall.  This function also draws a blue line segment
// that tracks the position of the avatar as it moves.
void MoveForward();

// Rotate the direction the avatar is facing clockwise by 90 degrees.
void TurnRight();

// Rotate the direction the avatar is facing counterclockwise by 90 degrees.
void TurnLeft();

// Returns true if the avatar is facing a wall.
bool IfFacingWall();

// Returns true if the avatar is outside the maze.
bool IfOutside();

#endif
